# Todo
# Have the vault + mkdocs folder
# Use the metadata from YAFPA aka : folder
# Add css for img flags
# Add customization in mkdocs yml (logo ; description)
# Admonition code block (as always)
# Add links in YML markdown
# Create folder when category / folder doesn't exist ;)



"""
Convert one file function.
"""

import os
import sys
from datetime import datetime
from pathlib import Path
from rich.console import Console
import frontmatter
import yaml

from mkdocs_obsidian.common import (
    file_checking as check,
    conversion as convert,
    config as setup,
    global_value as value,
)


def convert_one(ori, git: bool, meta: int, obsidian=False):
    """
    Function to start the conversion of *one* specified file.
    :param ori: path to file to convert
    :param git: if True, push to git
    :param meta: If 1 update the metadata's source file
    :param obsidian: Disable markup
    :return: None
    """
    file_name = os.path.basename(ori).upper()
    console = Console()
    try:
        yaml_front = frontmatter.load(ori)
        priv = Path(value.POST)
        clipkey = "notes"
        if "category" in yaml_front.keys():
            if not yaml_front["category"]:
                priv = check.create_folder("hidden")
                clipkey = "hidden"
            else:
                priv = check.create_folder(yaml_front["category"])
                clipkey = yaml_front["category"]
        contents = convert.file_convert(ori, 1)
        checkfile = convert.file_write(ori, contents, priv, 1, meta)
        if checkfile and git:
            commit = f"Pushed {file_name.lower()} to blog"
            setup.git_push(commit, obsidian, "Push", file_name)
            convert.clipboard(ori, clipkey)
        elif checkfile and not git:
            if not obsidian:
                console.print(
                    f"[{datetime.now().strftime('%H:%M:%S')}] 🎉 Successfully converted"
                    f" [u blue bold]{file_name.lower()}[/]"
                )
            else:
                print(
                    f"[{datetime.now().strftime('%H:%M:%S')}] 🎉 Successfully converted"
                    f" {file_name.lower()}"
                )
    except yaml.YAMLError:
        sys.exit(
            f"Error in {file_name} : Your YAML frontmatter doesn't seem valid! Use"
            " https://jsonformatter.org/yaml-validator to correct it!"
        )
    sys.exit()



"""
Get the environment variables
"""

from pathlib import Path
import sys
import glob
import os
from dotenv import dotenv_values

import mkdocs_obsidian as obs
from mkdocs_obsidian.common import config

BASEDIR = obs.__path__[0]
try:
    import pyto

    BASEDIR = Path(BASEDIR)
    BASEDIR = BASEDIR.parent.absolute()
except ModuleNotFoundError:
    pass

ENV_PATH = Path(f"{BASEDIR}/.mkdocs_obsidian")

if not os.path.isfile(ENV_PATH):
    config.create_env()
else:
    with open(ENV_PATH, encoding="utf-8") as f:
        components = f.read().splitlines()
        if len(components) == 0:
            config.create_env()
        else:
            for data in components:
                VAULT = data.split("=")
                if len(data) == 0 or len(VAULT[1]) == 0:
                    config.create_env()

# In case of error
env = dotenv_values(ENV_PATH)
try:
    BASEDIR = Path(env["blog_path"]).expanduser()
    VAULT = Path(env["vault"]).expanduser()
    WEB = env["blog"]
    try:
        SHARE = env["share"]
    except KeyError:
        SHARE = "share"
        with open(ENV_PATH, "a", encoding="utf-8") as f:
            f.write("share=share")
    try:
        INDEX_KEY = env["index_key"]
    except KeyError:
        INDEX_KEY = "(i)"
        with open(ENV_PATH, "a", encoding="utf-8") as f:
            f.write("index_key=(i)")
except KeyError:
    with open(ENV_PATH, "r", encoding="utf-8") as f:
        vault_str = "".join(f.readlines(1)).replace("VAULT=", "").rstrip()
        basedir_str = "".join(f.readlines(2)).replace("blog_path=", "").rstrip()

        VAULT = Path(vault_str)
        BASEDIR = Path(basedir_str)
        WEB = "".join(f.readlines(3)).replace("blog=", "")
        SHARE = "".join(f.readlines(4)).replace("share=", "")
        INDEX_KEY = "".join(f.readlines(5)).replace("index_key=", "")
    with open(ENV_PATH, "a", encoding="utf-8") as f:
        if len(SHARE) == 0:
            SHARE = "share"
            f.write("share=share")
        if len(INDEX_KEY) == 0:
            INDEX_KEY = "(i)"
            f.write("index_key=(i)")
    if len(vault_str) == 0 or len(basedir_str) == 0 or len(WEB) == 0:
        sys.exit("Please provide a valid path for all config items")
except RuntimeError:
    BASEDIR = Path(env["blog_path"])
    VAULT = Path(env["vault"])
    WEB = env["blog"]
    SHARE = env["share"]
    INDEX_KEY = env["index_key"]
try:
    VAULT = VAULT.expanduser()
    BASEDIR = BASEDIR.expanduser()
except RuntimeError:
    sys.exit("Please provide a valid path for all config items")

POST = Path(f"{BASEDIR}/docs/notes")
IMG = Path(f"{BASEDIR}/docs/assets/img/")
VAULT_FILE = [
    x
    for x in glob.iglob(str(VAULT) + os.sep + "**", recursive=True)
    if os.path.isfile(x)
]



"""
Main program to convert file to material mkdocs.
"""

import os
import platform
import re
import shutil
import urllib.parse as url
from pathlib import Path

import frontmatter
import unidecode

from mkdocs_obsidian.common import (
    file_checking as check,
    global_value as config,
    metadata as mt,
    admonition as adm,
)

BASEDIR = Path(config.BASEDIR)
VAULT = Path(config.VAULT)
VAULT_FILE = config.VAULT_FILE
SHARE = config.SHARE


def get_image(image):
    """
    Check if the image exists in the VAULT
    :param image: str
    :return: bool or filepath to image
    """
    for filepath in VAULT_FILE:
        if unidecode.unidecode(os.path.basename(filepath)) == unidecode.unidecode(
            image
        ):
            return filepath
    return False


def copy_image(final_text):
    """
    Copy the image if exist
    :param final_text: str
    :return: None
    """
    list_text = final_text.split("!")
    if len(list_text) > 0:
        for i in list_text:
            link = re.search("(\[{2}|\().*\.(png|jpg|jpeg|gif)", i)
            if link:
                final_text = re.sub("(!?|\(|(%20)|\[|\]|\))", "", i)
                final_text = os.path.basename(final_text.split("|")[0])
                image_path = get_image(final_text)
                if image_path and os.path.isfile(image_path):
                    shutil.copyfile(
                        image_path, Path(f"{config.IMG}/{os.path.basename(image_path)}")
                    )


def clipboard(filepath, folder):
    """
    Copy file URL to clipboard
    :param filepath: str
    :param folder: str
    :return: None
    """
    filename = os.path.basename(filepath)
    filename = filename.replace(".md", "")
    folder_key = os.path.basename(folder)
    if filename == folder:
        filename = ""
    paste = url.quote(f"{folder_key}/{filename}")
    clip = f"{config.WEB}{paste}"
    if "iPhone" in platform.uname().machine or "iPad" in platform.uname().machine:
        try:
            import pasteboard  # work with pyto

            pasteboard.set_string(clip)
        except ImportError:
            try:
                import clipboard  # work with pytonista

                clipboard.set(clip)
            except ImportError:
                print(
                    "Please, report issue with your OS and configuration to check if it"
                    " possible to use another clipboard manager"
                )
    else:
        try:
            # trying to use Pyperclip
            import pyperclip

            pyperclip.copy(clip)
        except ImportError:
            print(
                "Please, report issue with your OS and configuration to check if it"
                " possible to use another clipboard manager"
            )


def file_write(filepath, contents: list, folder, preserve=0, meta_update=1):
    """
    Write the new converted file and update metadata if meta_update is 0
    :param filepath: file to convert
    :param contents: File contents
    :param folder: folderpath in publish
    :param preserve: Change shared state in frontmatter if 1
    :param meta_update: Update frontmatter if meta_update = 0
    :return: True if file is created, False otherwise
    """
    file_name = os.path.basename(filepath)
    meta = frontmatter.load(filepath)
    if contents == "":
        return False
    if preserve == 0 and not meta.get(SHARE):
        check.delete_file(filepath, folder, meta_update)
        return False
    if os.path.splitext(file_name)[0] == Path(folder).name:
        file_name = "index.md"
    with open(Path(f"{folder}/{file_name}"), "w", encoding="utf-8") as new_notes:
        for line in contents:
            new_notes.write(line)
    if meta_update == 0:
        if preserve == 1 and not meta.get(SHARE):
            meta[SHARE] = True
            mt.update_frontmatter(filepath, 1)
        else:
            mt.update_frontmatter(filepath, 0)
    return True


def read_custom():
    """
    read custom css
    :return: A list of the id in the CSS file
    """
    id_css = []
    with open(
        Path(f"{BASEDIR}/docs/assets/css/custom_attributes.css"), "r", encoding="utf-8"
    ) as css:
        for i in css.readlines():
            if i.startswith("#"):
                id_css.append(i.replace("{\n", "").strip())
    return id_css


def convert_hashtags(final_text: str):
    """
    Convert configured hashtags with ial CSS from custom.css
    :param final_text: A line of the contents to convert if contains hashtags
    :return: str
    """
    css = read_custom()
    token = re.findall("#\w+", final_text)
    token = list(set(token))
    for i in range(0, len(token)):
        if token[i] in css:
            final_text = final_text.replace(token[i], "")
            if final_text.startswith("#"):
                heading = re.findall("#", final_text)
                heading = "".join(heading)
                ial = (
                    heading
                    + " **"
                    + final_text.replace("#", "").strip()
                    + "**{: "
                    + token[i]
                    + "}  \n"
                )
            else:
                ial = "**" + final_text.strip() + "**{: " + token[i] + "}  \n"
            final_text = final_text.replace(final_text, ial)
        else:
            ial = (
                "**"
                + token[i].replace("#", " ").strip()
                + "**{: "
                + token[i].strip()
                + "}{: .hash}  \n"
            )
            final_text = final_text.replace(token[i], ial, 1)
    return final_text


def index_path(file_name):
    file = [x for x in VAULT_FILE if os.path.basename(x) == file_name + ".md"]
    index = "index"
    if file:
        metadata = frontmatter.load(file[0])
        if metadata.get("category") and Path(metadata["category"]).name == file_name:
            category = str(Path(metadata["category"])).replace(
                "\\", "/"
            )  # Normalize path on Windows
            index = "/" + category + "/index.md"
    return index


def index_citation(final_text: str):
    """
    :param final_text: Line to check, wikilinks or MD links
    :return: Invert the alias with the name to get the index citation
    """
    INDEX_KEY = config.INDEX_KEY
    if ") [" in final_text:
        cited = (
            re.search(
                rf"(\[{2}.*\|(.*)"
                + re.escape(INDEX_KEY)
                + r"(.*)\]{2}|\[.*"
                + re.escape(INDEX_KEY)
                + r".*]\(.*\))",
                final_text,
            )
            .group()
            .split(") [")
        )
    else:
        cited = (
            re.search(
                r"(\[{2}.*\|.*"
                + re.escape(INDEX_KEY)
                + r".*\]{2}|\[.*"
                + re.escape(INDEX_KEY)
                + r".*]\(.*\))",
                final_text,
            )
            .group()
            .split("]]")
        )
    for i in cited:
        if i != "" and not "www" in i:
            if re.search(rf"\|.*" + re.escape(INDEX_KEY) + rf".*", i):
                file_name = (
                    re.search(rf"\|.*" + re.escape(INDEX_KEY) + rf".*", i)
                    .group()
                    .replace(INDEX_KEY, "")
                    .replace("|", "")
                    .strip()
                )
                if len(file_name) == 0:
                    file_name = (
                        re.search("(.*)\|", i)
                        .group(1)
                        .replace("|", "")
                        .replace("[", "")
                        .replace(INDEX_KEY, "")
                    )
                index = index_path(file_name)
                cite = f"[[{index}|" + file_name.strip()
                final_text = final_text.replace(i, cite)
            elif re.search(r"(.*)" + re.escape(INDEX_KEY) + r"(.*)\]", i):
                file_name = re.search(r"(.*)" + re.escape(INDEX_KEY) + r"(.*)\]", i)
                file_name = (
                    file_name.group()
                    .replace(INDEX_KEY, "")
                    .replace("[", "")
                    .replace("]", "")
                )
                if len(file_name) == 0:
                    file_name = re.search("\]\((.*)", i).group(1).replace(")", "")
                index = index_path(file_name)
                cite = "[" + file_name + f"]({index})"
                final_text = (
                    final_text.replace(i, cite)
                    .replace("))", ")")
                    .replace("[[", "[")
                    .replace("]]", "]")
                )
    return final_text


def file_convert(filepath, force=0):
    """
    Read the filepath and convert each line based on regex condition.
    :param filepath: path to file
    :param force: deletion option
    :return: converted contents
    """
    final = []
    INDEX_KEY = config.INDEX_KEY
    meta = frontmatter.load(filepath)
    lines = meta.content.splitlines(True)
    if force != 1 and not meta.get(SHARE):
        return final
    lines = adm.admonition_trad(lines)
    for line in lines:
        final_text = line
        if not final_text.strip().endswith("%%") and not final_text.strip().startswith(
            "%%"
        ):
            # Skip obsidian comments
            # Check and copy image
            copy_image(final_text)
            if not "`" in final_text:
                final_text = re.sub(
                    "\%{2}(.*)\%{2}", "", final_text
                )  # remove obsidian comments
            if (
                re.search(r"\\U\w+", final_text) and not "Users" in final_text
            ):  # Fix emoji if bug because of frontmatter
                emojiz = re.search(r"\\U\w+", final_text)
                emojiz = emojiz.group().strip().replace('"', "")
                convert_emojiz = (
                    emojiz.encode("ascii")
                    .decode("unicode-escape")
                    .encode("utf-16", "surrogatepass")
                    .decode("utf-16")
                )
                final_text = re.sub(r"\\U\w+", convert_emojiz, final_text)
            if re.search(
                rf"\[\[?(.*)" + re.escape(INDEX_KEY) + r"(.*)\]\]?", final_text
            ):
                # fix pagination.indexes page citation, exclude image/embed file
                final_text = index_citation(final_text)
            if re.search("#\w+", final_text) and not re.search(
                "(`|\[{2}|\()(.*)#(.*)(`|\]{2}|\))", final_text
            ):  # search hashtags not in link
                # Convert hashtags
                final_text = convert_hashtags(final_text)
            elif re.fullmatch(
                "\\\\", final_text.strip()
            ):  # New line when using "\" in obsidian filepath
                final_text = "\n"

            elif final_text == "```\n":
                # fix code newlines for material mkdocs
                final_text = final_text + "\n"

            final.append(final_text)
    for k, v in meta.metadata.items():
        if isinstance(v, str):
            meta.metadata[k] = '"' + v + '"'
    meta_list = [f"{k}: {v}\n" for k, v in meta.metadata.items()]
    meta_list.insert(0, "---\n")
    meta_list.insert(len(meta_list) + 1, "---\n")
    final = meta_list + final
    return final



"""
Update metadata in the file, if option is used.
"""

import os
import re
from pathlib import Path
import urllib.parse as url

import frontmatter
from mkdocs_obsidian.common import global_value as config

BASEDIR = Path(config.BASEDIR)
WEB = config.WEB
SHARE = config.SHARE


def update_frontmatter(filepath, link=1):
    """
    If link = 1, update the frontmatter with new publish URL
    Also, update the share state if convert_one.
    :param filepath: path to source file
    :param link: if 1 add link to the metadata
    :return: None
    """
    with open(filepath, "r", encoding="utf8") as metadata:
        meta = frontmatter.load(metadata)
    if meta.get("tag"):
        tag = meta["tag"]
    elif meta.get("tags"):
        tag = meta["tags"]
    else:
        tag = ""
    meta.metadata.pop("tag", None)
    meta.metadata.pop("tags", None)
    if meta.metadata.get("category"):
        folder = meta.metadata["category"]
    else:
        folder = "notes"

    with open(filepath, "w", encoding="utf-8") as f:
        filename = os.path.basename(filepath)
        filename = filename.replace(".md", "")
        if filename == os.path.basename(folder):
            filename = ""
        path_url = url.quote(f"{folder}/{filename}")
        clip = f"{WEB}{path_url}"
        meta["link"] = clip
        update = frontmatter.dumps(meta, sort_keys=False)
        meta = frontmatter.loads(update)
        if link != 1:
            meta.metadata.pop("link", None)
        elif link == 1 and SHARE == 1 and (not meta.get(SHARE)):
            meta[SHARE] = "true"
        if tag != "":
            meta["tag"] = tag
        update = frontmatter.dumps(meta, sort_keys=False)
        if re.search(r"\\U\w+", update):
            emojiz = re.search(r"\\U\w+", update)
            emojiz = emojiz.group().strip()
            raw = r"{}".format(emojiz)
            try:
                convert_emojiz = (
                    raw.encode("ascii")
                    .decode("unicode_escape")
                    .encode("utf-16", "surrogatepass")
                    .decode("utf-16")
                )
                update = re.sub(r'"\\U\w+"', convert_emojiz, update)
            except UnicodeEncodeError:
                pass
        f.write(update)



"""
Convert all file in a vault folder.
"""

import os
import sys
from datetime import datetime
from pathlib import Path

import frontmatter
import yaml
from rich.progress import track
from rich.rule import Rule
from rich.markdown import Markdown
from rich.console import Console
from rich import print
from mkdocs_obsidian.common import (
    config,
    global_value as gl,
    file_checking as check,
    conversion as convert,
)

BASEDIR = gl.BASEDIR
VAULT = gl.VAULT
VAULT_FILE = gl.VAULT_FILE
SHARE = gl.SHARE
INDEX_KEY = gl.INDEX_KEY


def exclude_folder(filepath: str):
    """
    Check if the file is in an excluded folder
    :param filepath: file to check
    :return: boolean
    """
    config_folder = Path(f"{BASEDIR}/exclude_folder.yml")
    if os.path.exists(config_folder):
        with open(config_folder, "r", encoding="utf-8") as file_config:
            try:
                folder = yaml.safe_load(file_config)
            except yaml.YAMLError as exc:
                print(exc)
                sys.exit(1)
        return any(str(Path(file)) in filepath for file in folder)
    return False


def dest(filepath: str, folder: str):
    """
    Return the path of the final file
    :param filepath: file to convert
    :param folder: final folder
    :return: str
    """
    file_name = os.path.basename(filepath)
    destination = Path(f"{folder}/{file_name}")
    return str(destination)


def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False):
    """
    Search file to publish
    :param obsidian: Use normal printing for obsidian_shell
    :param preserve: if 1 force update
    :param stop_share: remove stoped shared file if 1
    :param meta: Update the metadata if 1
    :param vault_share: If all the vault need to be shared
    :return: Contents of the notes
    """
    filespush = []
    check_file = False
    clipkey = "notes"
    description = "[cyan u]Scanning\n"
    for filepath in track(
        VAULT_FILE, description=description, total=len(VAULT_FILE), disable=obsidian
    ):
        if (
            filepath.endswith(".md")
            and "excalidraw" not in filepath
            and not exclude_folder(filepath)
        ):
            try:
                yaml_front = frontmatter.load(filepath)
                clipkey = yaml_front.get("category", "notes")
                if not clipkey:
                    clipkey = "hidden"
                if yaml_front.get(SHARE) or vault_share == 1:
                    folder = check.create_folder(clipkey, 0)
                    if preserve == 0:  # preserve
                        if yaml_front.get("update") is False:
                            update = 1
                        else:
                            update = 0

                        if check.skip_update(
                            filepath, folder, update
                        ) or not check.modification_time(filepath, folder, update):
                            check_file = False
                        else:
                            contents = convert.file_convert(filepath, vault_share)
                            if check.diff_file(filepath, folder, contents, update):
                                check_file = convert.file_write(
                                    filepath, contents, folder, meta
                                )
                            else:
                                check_file = False
                    elif preserve == 1:  # force deletions
                        contents = convert.file_convert(filepath, vault_share)
                        check_file = convert.file_write(
                            filepath, contents, folder, meta
                        )
                    msg_folder = os.path.basename(folder)
                    destination = dest(filepath, folder)
                    if check_file:
                        filespush.append(
                            "Added :"
                            f" {os.path.basename(destination).replace('.md', '')} in"
                            f" [{msg_folder}]"
                        )
                elif stop_share == 1:
                    folder = check.create_folder(clipkey, 1)
                    file_name = os.path.basename(filepath).replace(".md", "")
                    if file_name == os.path.basename(folder):
                        filepath = filepath.replace(file_name, "index")
                    if check.delete_file(filepath, folder, meta):
                        msg_folder = os.path.basename(folder)
                        destination = dest(filepath, folder)
                        filespush.append(
                            "Removed :"
                            f" {os.path.basename(destination).replace('.md', '')} from"
                            f" [{msg_folder}]"
                        )
            except yaml.YAMLError:
                print(f"Skip [u bold red]{filepath}[/] because of YAML error.\n")
            except Exception as e:
                print(
                    f"Skip [u bold red]{filepath}[/] because of an unexpected error :"
                    f" {e}\n"
                )
    return filespush, clipkey


def obsidian_simple(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
    """
    Main function to convert multiple file in obsidian shell
    :param delopt: Force deletion if True
    :param git: Git push if True
    :param stop_share: Delete stoped shared file if 0
    :param meta: Update frontmatter if 1
    :param vault_share: Share all file in vault if 1
    :return: None
    """
    if not git:
        git_info = "No push"
    else:
        git_info = "Push"
    time_now = datetime.now().strftime("%H:%M:%S")
    msg_info = ""
    if vault_share == 1:
        msg_info = "\n- Share entire vault [**ignore share**]"
    if delopt:  # preservesdds
        print(
            f"[{time_now}] STARTING CONVERT ALL\n\n- {git_info}\n- Force"
            f" deletion{msg_info}"
        )
        new_files, clipkey = search_share(
            1, stop_share, meta, vault_share, obsidian=True
        )
    else:
        print(f"[{time_now}] STARTING CONVERT ALL\n- {git_info}\n{msg_info}")
        new_files, clipkey = search_share(
            0, stop_share, meta, vault_share, obsidian=True
        )
    if len(new_files) > 0:
        add_msg = ""
        remove_msg = ""
        for markdown_msg in new_files:
            if "removed" in markdown_msg.lower():
                remove_msg = (
                    remove_msg + "\n- " + markdown_msg.replace("Removed : ", "")
                )
            elif "added" in markdown_msg.lower():
                add_msg = add_msg + "\n- " + markdown_msg.replace("Added : ", "")
        remove_info = ""
        add_info = ""
        if len(remove_msg) > 0:
            remove_info = "🗑 Removed from blog : "
        if len(add_msg) > 0:
            add_info = "🎉 Added to blog :"
        commit = add_msg + remove_msg
        if git:
            if len(new_files) == 1:
                commit = "".join(new_files)
                markdown_msg = commit[commit.find(":") + 2 : commit.rfind("in") - 1]
                convert.clipboard(markdown_msg, clipkey)
            commit = f"Updated :\n\n {commit}\n"
            config.git_push(
                commit,
                True,
                add_info=add_info,
                rmv_info=remove_info,
                add_msg=add_msg,
                remove_msg=remove_msg,
            )
        else:
            print(
                f"[{datetime.now().strftime('%H:%M:%S')}]"
                f"{add_info}: {add_msg}\n{remove_info}: {remove_msg}"
            )
    else:
        print(f"[{datetime.now().strftime('%H:%M:%S')}] No modification 😶")
    sys.exit()


def convert_all(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
    """
    Main function to convert multiple file
    :param delopt: Force deletion if True
    :param git: Git push if True
    :param stop_share: Delete stoped shared file if 0
    :param meta: Update frontmatter if 1
    :param vault_share: Share all file in vault if 1
    :return: None
    """
    console = Console()
    if not git:
        git_info = "No push"
    else:
        git_info = "Push"
    time_now = datetime.now().strftime("%H:%M:%S")
    msg_info = ""
    if vault_share == 1:
        msg_info = "\n- Share entire vault [**ignore share**]"
    if delopt:  # preservesdds
        console.print(
            Rule(
                f"[[i not bold sky_blue2]{time_now}[/]] [deep_sky_blue3 bold]STARTING"
                " CONVERT[/] [[i sky_blue2]ALL[/]]",
                align="center",
                end="",
                style="deep_sky_blue3",
            ),
            Markdown(f"- {git_info}\n- Force deletion{msg_info}", justify="full"),
            end=" ",
            new_line_start=True,
            justify="full",
        )
        new_files, clipkey = search_share(1, stop_share, meta, vault_share)
    else:
        console.print(
            Rule(
                f"[[i not bold sky_blue2]{time_now}[/]] [deep_sky_blue3 bold]STARTING"
                " CONVERT[/] [[i sky_blue2]ALL[/]]",
                align="center",
                end="",
                style="deep_sky_blue3",
            ),
            Markdown(f"- {git_info}\n{msg_info}"),
            " ",
            new_line_start=True,
        )
        new_files, clipkey = search_share(0, stop_share, meta, vault_share)
    if len(new_files) > 0:
        add_msg = ""
        remove_msg = ""
        for markdown_msg in new_files:
            if "removed" in markdown_msg.lower():
                remove_msg = (
                    remove_msg + "\n- " + markdown_msg.replace("Removed : ", "")
                )
            elif "added" in markdown_msg.lower():
                add_msg = add_msg + "\n- " + markdown_msg.replace("Added : ", "")
        remove_info = ""
        add_info = ""
        if len(remove_msg) > 0:
            remove_info = "🗑 [u bold red]Removed from blog : "
        if len(add_msg) > 0:
            add_info = "🎉 [u bold sky_blue2]Added to blog :"
        commit = add_msg + remove_msg
        if git:
            if len(new_files) == 1:
                commit = "".join(new_files)
                markdown_msg = commit[commit.find(":") + 2 : commit.rfind("in") - 1]
                convert.clipboard(markdown_msg, clipkey)
            commit = f"**Updated** : \n {commit}\n"
            config.git_push(
                commit,
                add_info=add_info,
                rmv_info=remove_info,
                add_msg=add_msg,
                remove_msg=remove_msg,
            )
        else:
            console.print(
                f"[[i not bold sky_blue2]{datetime.now().strftime('%H:%M:%S')}[/]]"
                f" {add_info}",
                Markdown(add_msg),
                remove_info,
                Markdown(remove_msg),
                end=" ",
            )
    else:
        console.print(
            f"[[i not bold sky_blue2]{datetime.now().strftime('%H:%M:%S')}[/]]",
            Markdown("*No modification 😶*"),
            end=" ",
        )
    sys.exit()



import argparse
import os
import sys
from datetime import datetime
from rich.markdown import Markdown
from rich.console import Console
from rich import print
from pathlib import Path

try:
    sys.stdin.reconfigure(encoding="utf-8")
    sys.stdout.reconfigure(encoding="utf-8")
except AttributeError:
    pass

from mkdocs_obsidian.common import (
    config as setup,
    global_value as value,
    convert_all as all,
    convert_one as one,
    file_checking as check,
)


def search_shortcuts(file):
    """
    Search a specific file in vault, using shortcuts on IOS
    :param file: str (filepath)
    :return: str (filepath) / False
    """
    if not file.endswith(".md"):
        file = file + ".md"
    for md in value.VAULT_FILE:
        if os.path.basename(md) == os.path.basename(file):
            return md
    return False


def obsidian_shell(file="0", meta_update=0, vault_share=0, git=True):
    """
    :param file: Filepath. 0 for all shared files
    :param meta_update: Disable-enable metadata update in source file
    :param vault_share: Share all vault.
    :param git: If true, push to git
    :return: /
    """

    if file == "0":
        all.obsidian_simple(False, git, 1, 0, vault_share)
    elif not os.path.exists(Path(file)):
        file = search_shortcuts(file)
        if not file:
            print("File not found.")
            sys.exit()
        one.convert_one(file, git, meta_update)
    elif file != "0" and os.path.exists(Path(file)):
        one.convert_one(file, git, meta_update)
    sys.exit()


def mobile_shortcuts(file="0", meta_update=0, vault_share=0):
    """
    Main function using on mobile
    :param meta_update: Enable the metadata update
    :param file: File to convert
    :param vault_share: int (bool)
    :return: None
    """
    if file == "0":
        all.convert_all(False, False, 1, 0, vault_share)
    elif not os.path.exists(Path(file)):
        file = search_shortcuts(file)
        if not file:
            print("[u red]File not found.")
            sys.exit()
        one.convert_one(file, False, meta_update)
    elif file == "--c":
        setup.create_env()
        sys.exit()
    elif file != "0" and os.path.exists(Path(file)):
        one.convert_one(file, False, meta_update)


def main():
    """
    Main function using in CLI
    :return: None
    """
    parser = argparse.ArgumentParser(
        description=(
            "Create file in docs and relative folder, move image in assets, convert"
            " admonition code_blocks, add links and push."
        )
    )
    group_files = parser.add_mutually_exclusive_group()
    group_git = parser.add_mutually_exclusive_group()
    group_git.add_argument(
        "--git", "--g", "--G", help="No commit and no push to git", action="store_false"
    )
    group_git.add_argument(
        "--mobile",
        "--shortcuts",
        "--s",
        "--S",
        help="Use mobile shortcuts fonction without push.",
        action="store_true",
    )
    parser.add_argument(
        "--meta",
        "--m",
        "--M",
        help="Update the frontmatter with link",
        action="store_true",
    )
    parser.add_argument(
        "--keep",
        "--k",
        "--K",
        help="Keep deleted file from vault and removed shared file",
        action="store_true",
    )
    parser.add_argument(
        "--config", "--c", "--C", help="Edit the config file", action="store_true"
    )
    parser.add_argument("--obsidian", help=argparse.SUPPRESS, action="store_true")
    parser.add_argument(
        "--force",
        "--d",
        "--D",
        help="Force conversion - only work if path not specified",
        action="store_true",
    )
    group_files.add_argument(
        "--filepath",
        "--f",
        help="Filepath of the file you want to convert",
        action="store",
        required=False,
    )
    group_files.add_argument(
        "--ignore",
        "--ignore-share",
        "--no-share",
        "--i",
        "--vault",
        help="Convert the entire vault without relying on share state.",
        action="store_true",
    )
    console = Console()
    args = parser.parse_args()
    if args.config:
        setup.create_env()
        sys.exit()
    ori = args.filepath
    meta_update = 1
    if args.meta:
        meta_update = 0
    delopt = False
    if args.force:
        delopt = True
    ng = args.git
    share_vault = 0
    if args.ignore:
        share_vault = 1
    if not args.keep:
        info = check.delete_not_exist()
        if len(info) > 1:
            info[0] = "- " + info[0]
            info_str = "\n- ".join(info)
            if args.obsidian:
                console.print(
                    f'[[i not bold sky_blue2]{datetime.now().strftime("%H:%M:%S")}[/]]'
                    " 🗑️[u red bold]Delete from blog :[/]",
                    Markdown(info_str),
                    end="",
                )
            else:
                print(
                    f'[{datetime.now().strftime("%H:%M:%Sf")}] 🗑️ Delete from blog:'
                    f" {info_str}"
                )
        elif len(info) == 1:
            info_str = info[0]
            if args.obsidian:
                console.print(
                    f"🗑️ [u red bold] Delete[/] [bold red i] {info_str}[/] [u red"
                    " bold]from blog[/]"
                )
            else:
                print(f"Delete {info_str} from blog.")
        stop_share = 1
    else:
        stop_share = 0
    if ori:
        if args.obsidian:
            obsidian_shell(ori, meta_update, share_vault, ng)
            sys.exit()
        elif args.mobile:
            mobile_shortcuts(ori, meta_update, share_vault)
            sys.exit()
        elif os.path.exists(Path(ori)):  # Share ONE
            one.convert_one(ori, ng, meta_update)
        else:
            print(f"[red bold]Error :[/] [u]{ori}[/] [red bold]doesn't exist.")
            sys.exit()
    else:
        if args.mobile:
            mobile_shortcuts("0", meta_update, share_vault)
            sys.exit()
        elif args.obsidian:
            obsidian_shell("0", meta_update, share_vault)
            sys.exit()
        all.convert_all(delopt, ng, stop_share, meta_update, share_vault)


if __name__ == "__main__":
    main()



"""
All function intended to check the file and their path.
"""

import glob
import os
import re
from pathlib import Path

import frontmatter
import yaml
from unidecode import unidecode

from mkdocs_obsidian.common import global_value as settings
from mkdocs_obsidian.common import convert_all as exclude
from mkdocs_obsidian.common import metadata as mt

BASEDIR = settings.BASEDIR
POST = settings.POST
VAULT = settings.VAULT
VAULT_FILE = settings.VAULT_FILE


def delete_not_exist():
    """
    Removes files that have been deleted from the vault
    :return: A list of deleted files
    """
    vault_file = []
    info = []
    excluded = []
    important_folder = ["assets", "css", "js", "logo", "script"]
    docs = Path(f"{BASEDIR}/docs/**")
    for note in VAULT_FILE:
        vault_file.append(os.path.basename(note))
        if exclude.exclude_folder(note):
            excluded.append(os.path.basename(note))
    for file in glob.iglob(str(docs), recursive=True):
        if not any(i in file for i in important_folder):
            if not re.search("(README|index|CNAME)", os.path.basename(file)) and (
                os.path.basename(file) not in vault_file
                or os.path.basename(file) in excluded
            ):  # or if file in file_excluded
                try:
                    if os.path.isfile(Path(file)):
                        os.remove(Path(file))
                        folder = os.path.dirname(Path(file))
                        if len(os.listdir(folder)) == 0:
                            # Delete folder
                            os.rmdir(folder)
                        info.append(os.path.basename(file))
                except PermissionError:
                    pass
                except IsADirectoryError:
                    pass
    return info


def diff_file(filepath: str, folder: str, contents: list, update=0):
    """
    Check the difference between file in vault and file in publish.
    Check if the new converted file = the file on publish.
    :param filepath: filepath
    :param folder: folderpath
    :param contents: Contents of the file to check
    :param update: check if update is forced
    :return: boolean
    """
    filename = os.path.basename(filepath)
    if check_file(filename, folder) == "EXIST":
        if update == 1:
            return False
        if filename.replace(".md", "") == os.path.basename(folder):
            filename = "index.md"
        note = Path(f"{folder}/{filename}")
        retro_old = retro(note)
        meta_old = frontmatter.load(note)
        meta_old = meta_old.metadata
        meta_old.pop("link", None)
        try:
            front_temp = frontmatter.loads("".join(contents))
        except yaml.YAMLError:
            print(f"Skip {filepath} : YAML Error")
            return False  # skip
        new_version = retro(contents, 1)
        meta_new = front_temp.metadata
        meta_new.pop("link", None)
        if (
            new_version == retro_old
            and sorted(meta_old.keys()) == sorted(meta_new.keys())
            and sorted(str(meta_old.values())) == sorted(str(meta_new.values()))
        ):
            return False
        return True
    return True  # Si le fichier existe pas, il peut pas être identique


def retro(file, opt=0):
    """
    Remove metadata from note
    :param file: str or list
    :param opt: if filepath is a list or a filepath
    :return: the frontmatter of the note
    """
    notes = []

    if opt == 0:
        try:
            metadata = frontmatter.load(file)
        except yaml.YAMLError:
            os.remove(file)
            return notes
    else:
        metadata = frontmatter.loads("".join(file))
    file = metadata.content.split("\n")
    for line in file:
        notes.append(line)
    return notes


def create_folder(category: str, share=0):
    """
    create a folder based on the category key as 'folder1/folder2/.../'
    :param category: string
    :param share: status of the note
    :return: folderpath (Path)
    """
    if category != "":
        folder = Path(f"{BASEDIR}/docs/{category}")
        try:
            if share == 0:
                folder.mkdir(parents=True, exist_ok=True)
        except OSError:
            folder = Path(POST)
    else:
        folder = Path(POST)
    return folder


def modification_time(filepath: str, folder: str, update: int):
    """
    check the modification time : return true if file modified since the last push.
    :param filepath: file to check
    :param folder: folder in the blog
    :param update: skip check if 0 (force update)
    :return: boolean
    """
    if update == 0:
        return True  # Force update
    filename = os.path.basename(filepath)
    filepath = Path(filepath)
    note = Path(f"{folder}/{filename}")
    if os.path.isfile(note):
        return filepath.stat().st_mtime > note.stat().st_mtime
    return True  # file doesn't exist


def skip_update(filepath: str, folder: str, update: int):
    """
    check if file exist + update is false
    """
    filepath = Path(filepath)
    return update == 1 and check_file(filepath, folder) == "EXIST"


def check_file(filepath, folder: str):
    """
    check if the requested file exist or not in publish.
    :param filepath: filepath
    :param folder: folderpath in publish
    :return: "EXIST" or "NE"
    """
    file = os.path.basename(filepath)
    folder_check = Path(folder).name
    if file.replace(".md", "") == folder_check:
        file = "index.md"
    publish = Path(f"{folder}/{file}")
    if os.path.isfile(publish):
        return "EXIST"
    return "NE"


def delete_file(filepath: str, folder: str, meta_update=1) -> bool:
    """
    Delete the requested file
    :param filepath: filepath
    :param folder: folder path
    :param meta_update:  update the metadata if 0
    :return: boolean
    """
    path = Path(folder)
    try:
        for file in os.listdir(path):
            filename = unidecode(os.path.basename(filepath))
            filecheck = unidecode(os.path.basename(file))
            if filecheck == filename:
                os.remove(Path(f"{path}/{file}"))
                if meta_update == 0:
                    mt.update_frontmatter(filepath, 0)
                return True
        if len(os.listdir(path)) == 0:
            os.rmdir(path)
    except FileNotFoundError:
        pass
    return False



"""
A terrifing code to convert admonition code blocks to material code blocks.
"""

import os
import re
import sys
from itertools import zip_longest
from pathlib import Path
import yaml
from mkdocs_obsidian.common import global_value as config

BASEDIR = config.BASEDIR


def code_blocks(start_list: list, end_list: list):
    """
    Check all code blocks in the contents
    :param start_list: List of all started codeblocs
    :param end_list: list of all ended code blocks
    :return: merged list
    """
    start_bug = []
    end_bug = []
    bug = list(zip_longest(start_list, end_list, fillvalue=-1))
    for i in bug:
        if i[0] > i[1]:
            start_bug.append(i[0])
        elif i[0] == -1:
            end_bug.append(i[1])
    merged = []
    for i in start_bug:
        for j in end_bug:
            if i < j:
                merged.append((i, j))
    no_bug = [
        (x, y)
        for x, y in zip_longest(start_list, end_list, fillvalue=-1)
        if x != -1 and x < y
    ]
    merged = no_bug + merged
    return merged


def admonition_trad(file_data: list):
    """
    Change all admonition to material admonition
    :param file_data: Contents of the file
    :return: Admonition Converted contents
    """
    code_index = 0
    code_dict = {}
    start_list = []
    end_list = []
    adm_list = [
        "note",
        "seealso",
        "abstract",
        "summary",
        "tldr",
        "info",
        "todo",
        "tip",
        "hint",
        "important",
        "success",
        "check",
        "done",
        "question",
        "help",
        "faq",
        "warning",
        "caution",
        "attention",
        "failure",
        "fail",
        "missing",
        "danger",
        "error",
        "bug",
        "example",
        "exemple",
        "abstract",
        "quote",
        "cite",
    ]
    custom = []
    admonition_custom = False
    if os.path.exists(Path(f"{BASEDIR}/assets/script/custom_admonition.yml")):
        admonition_custom = Path(f"{BASEDIR}/assets/script/custom_admonition.yml")
    elif os.path.exists(Path(f"{BASEDIR}/custom_admonition.yml")):
        admonition_custom = Path(f"{BASEDIR}/custom_admonition.yml")

    if admonition_custom:
        with open(admonition_custom, "r", encoding="utf-8") as stream:
            try:
                custom = yaml.safe_load(stream)
            except yaml.YAMLError:
                sys.exit(
                    f"Error in {admonition_custom} : Your YAML frontmatter doesn't seem"
                    " valid! Use https://jsonformatter.org/yaml-validator to"
                    " correct it!"
                )
    adm_list = adm_list + custom
    for i in range(0, len(file_data)):
        if re.search("[`?!]{3}( ?)\w+(.*)", file_data[i]):
            start = i
            start_list.append(start)
        if re.match("^```$", file_data[i]) or re.match("--- admonition", file_data[i]):
            end = i
            end_list.append(end)
    merged = code_blocks(start_list, end_list)
    for i, j in merged:
        code = {code_index: (i, j)}
        code_index = code_index + 1
        code_dict.update(code)
    for ln in code_dict.values():
        ad_start = ln[0]
        ad_end = ln[1]
        ad_type = re.search("[`!?]{3}\+?( ?)ad-\w+", file_data[ad_start])
        if ad_type:
            ad_type = re.sub("[`!?]{3}\+?( ?)ad-", "", ad_type.group())
            adm = "b"
            if re.search("[!?]{3} ad-(\w+) (.*)", file_data[ad_start]):
                title = re.search("[!?]{3}\+? ad-(\w+) (.*)", file_data[ad_start])
                adm = "MT"
                title = title.group(2)
            first_block = re.search("ad-(\w+)", file_data[ad_start])
            if first_block:
                file_data[ad_end] = "\n"
            adm_ad_type_code = first_block.group().replace("ad-", "")
            if adm_ad_type_code not in adm_list:
                first_block = "note"
            else:
                first_block = first_block.group()
            if adm == "b":
                first_block = (
                    "\n!!! " + first_block.replace("ad-", "") + " place_title_here"
                )
            else:
                first_block = re.search(
                    "[!?]{3}\+? ad-(\w+) (.*)", file_data[ad_start]
                ).group()
                first_block = first_block.replace("ad-", "")
                title_block = '"' + title + '"'
                first_block = first_block.replace(title, title_block)

            file_data[ad_start] = re.sub(
                "[`!?]{3}( ?)ad-(.*)", first_block, file_data[ad_start]
            )
            for i in range(ad_start, ad_end):
                if adm == "b" and file_data[i] == "collapse: open":
                    file_data[ad_start] = file_data[ad_start].replace("!!!", "???")
                    file_data[i] = ""
                elif adm == "b" and "collapse:" in file_data[i]:
                    file_data[ad_start] = file_data[ad_start].replace("!!!", "???+")
                    file_data[i] = ""
                elif adm == "b" and "title:" in file_data[i]:
                    title = '"' + file_data[i].replace("title:", "").strip() + '"'
                    if title == "":
                        title = '""'
                    file_data[ad_start] = file_data[ad_start].replace(
                        "place_title_here", title
                    )
                    file_data[i] = ""

                elif "icon:" in file_data[i]:
                    file_data[i] = ""
                elif "color:" in file_data[i]:
                    file_data[i] = ""
                elif len(file_data[i]) == 1 and adm == "b":  # change this
                    file_data[i] = "\t  \n"
                else:
                    file_data[i] = "\t" + file_data[i]
            if "place_title_here" in file_data[ad_start]:
                file_data[ad_start] = file_data[ad_start].replace(
                    "place_title_here", ""
                )
            file_data[ad_start] = file_data[ad_start].lstrip()
            file_data[ad_end] = file_data[ad_end].lstrip()
    return file_data



"""
Function to create environment variables and push to git.
"""

import os.path
import subprocess
import sys
from datetime import datetime
from time import sleep
from pathlib import Path
from rich.console import Console
from rich.markdown import Markdown
from rich import print
import mkdocs_obsidian as obs


def pyto_environment(console):
    """
    Use pyto bookmark to get path on IOS
    :param console: rich console
    :return vault_path ; blog_path
    """
    import bookmarks as bm

    vault = ""
    blog = ""
    console.print("Please provide your [u bold]obsidian vault[/] path: ")
    sleep(10)  # The user needs to read the message !
    vault = bm.FolderBookmark()
    vault_path = vault.path
    console.print("Please provide the [u bold]blog[/] repository path: ")
    sleep(10)  # The user needs to read the message !
    blog = bm.FolderBookmark()
    blog_path = blog.path
    return vault_path, blog_path


def legacy_environment(console):
    """
    Ask environment without using pyto bookmark
    :param console: rich console
    :return vault_path, blog_path
    """
    vault = ""
    blog = ""
    while vault == "" or not os.path.isdir(vault):
        vault = str(
            console.input("Please provide your [u bold]obsidian vault[/] path: ")
        )
    while blog == "" or not os.path.isdir(blog):
        blog = str(
            console.input("Please provide the [u bold]blog[/] repository path: ")
        )
    return vault, blog


def ashell_environment(console):
    """
    Relly on pickFolder in ashell to create the environment
    :param console: rich console
    :return vault_path, blog_path
    """
    vault = ""
    blog = ""
    console.print("Please provide your [u bold]obsidian vault[/] path: ")
    cmd = "pickFolder"
    sleep(10)  # The user needs to read the message !
    subprocess.Popen(cmd, stdout=subprocess.PIPE)
    # Now, the os.getcwd() change for the pickedFolder
    vault = os.getcwd()
    subprocess.Popen(cmd, stdout=subprocess.PIPE)
    console.print("Please provide the [u bold]blog[/] repository path: ")
    sleep(10)  # The user needs to read the message !
    subprocess.Popen(cmd, stdout=subprocess.PIPE)
    blog = os.getcwd()
    # return to default environment
    cmd = "cd"
    subprocess.Popen(cmd, stdout=subprocess.PIPE)
    return vault, blog


def check_url(blog_path: str):
    """
    check if the url is in the config file and return it
    :param blog_path: Publish absolute path
    :return: URL
    """
    web = ""
    try:
        blog_path = Path(blog_path).expanduser()
    except RuntimeError:
        blog_path = Path(blog_path)
    mkdocs = Path(f"{blog_path}/mkdocs.yml")
    try:
        with open(mkdocs, "r", encoding="utf-8") as mk:
            for i in mk:
                if "site_url:" in i:
                    web = i.replace("site_url:", "")
    except FileNotFoundError:
        pass
    return web


def create_env():
    """
    Create environment variable with:
        - vault = Path to the obsidian vault ;
        - blog = Path to the publish folder
        - blog_link = Publish url
        - share = Metadata key for sharing file
    :return: None
    """
    BASEDIR = obs.__path__[0]
    pyto_check = False
    try:
        import pyto

        pyto_check = True
        BASEDIR = Path(BASEDIR)
        BASEDIR = BASEDIR.parent.absolute()
    except ModuleNotFoundError:
        pass
    try:
        import subprocess

        process = subprocess.Popen("echo $TERM_PROGRAM", stdout=subprocess.PIPE)
        output, error = process.communicate()
        ashell = output.decode("utf-8").strip() == "a-Shell"
    except RuntimeError:
        ashell = False

    console = Console()
    env_path = Path(f"{BASEDIR}/.mkdocs_obsidian")
    print(f"[bold]Creating environnement in [u]{env_path}[/][/]")
    if pyto_check:
        vault, blog = pyto_environment(console)
    elif ashell:
        vault, blog = ashell_environment(console)
    else:
        vault, blog = legacy_environment(console)
    blog_link = check_url(blog).strip()
    if blog_link == "":
        blog_link = str(console.input("Please, provide the [u]URL[/] of your blog: "))
    share = str(
        console.input("Choose your share key name [i](default: [bold]share[/])[/]: ")
    )
    if share == "":
        share = "share"
    index_key = str(
        console.input(
            "If you want to use [u]folder note[/], please choose the key for citation"
            " [i](default: [bold](i)[/])[/]: "
        )
    )
    if index_key == "":
        index_key = "(i)"
    with open(env_path, "w", encoding="utf-8") as env:
        env.write(f"vault={vault}\n")
        env.write(f"blog_path={blog}\n")
        env.write(f"blog={blog_link}\n")
        env.write(f"share={share}\n")
        env.write(f"index_key={index_key}\n")
    post = Path(f"{blog}/docs/notes")
    img = Path(f"{blog}/docs/assets/img/")
    img.mkdir(exist_ok=True)
    post.mkdir(exist_ok=True)
    sys.exit("Environment created.")


def git_push(
    commit: str, obsidian=False, add_info="", rmv_info="", add_msg="", remove_msg=""
):
    """
    git push the modified files and print a message result
    :param commit: Commit information
    :param obsidian: Message without markup
    :param add_info: Adding title
    :param rmv_info: Removing title
    :param remove_msg: File removed
    :param add_msg: File added/modified
    :return: None
    """
    console = Console()
    try:
        import git
        from mkdocs_obsidian.common import global_value as gl

        BASEDIR = gl.BASEDIR
        repo = git.Repo(Path(f"{BASEDIR}/.git"))
        repo.git.add(".")
        repo.git.commit("-m", f"{commit}")
        origin = repo.remote("origin")
        origin.push()
        if not obsidian:
            console.print(
                f"[[i not bold sky_blue2]{datetime.now().strftime('%H:%M:%S')}][/]"
                f" {add_info}",
                Markdown(add_msg),
                rmv_info,
                Markdown(remove_msg),
                Markdown("---"),
                "🎉 Successful 🎉",
                end=" ",
            )
        else:
            print(
                f" 🎉 Successful 🎉 [{datetime.now().strftime('%H:%M:%S')}]"
                f" {add_info}:{add_msg}\n{rmv_info}:{remove_msg}\n"
            )
    except git.GitCommandError:
        if not obsidian:
            console.print(
                f"[[i not bold sky_blue2]{datetime.now().strftime('%H:%M:%S')}[/]]",
                Markdown("*No modification 😶*"),
                end=" ",
            )
        else:
            print(f"[{datetime.now().strftime('%H:%M:%S')}] No modification 😶")
    except ImportError:
        if not obsidian:
            console.print(
                f"[{datetime.now().strftime('%H:%M:%S')}]",
                Markdown(commit),
                "changed\nPlease, use another way to push your change 😶",
                end=" ",
            )
        else:
            print(
                f"[{datetime.now().strftime('%H:%M:%S')}] {commit} changed\n Please use"
                " another way to push your change 😶"
            )



from setuptools import setup, find_packages

version = "1.11.4"

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
with open("requirements.txt") as f:
    required = f.read().splitlines()
setup(
    name="obs2mk",
    python_requires=">=3.7",
    version=version,
    description="A script to share your obsidian vault (in partial way) using mkdocs",
    author="Mara-Li",
    author_email="mara-li@icloud.com",
    packages=find_packages(),
    install_requires=required,
    license="AGPL",
    keywords="obsidian, obsidian.md, free publish, publish, mkdocs, material",
    classifiers=[
        "Natural Language :: English",
        "Natural Language :: French",
        "Topic :: Text Processing :: Markup :: Markdown",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later"
        " (AGPLv3+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Mara-Li/mkdocs_obsidian_publish",
    entry_points={
        "console_scripts": ["obs2mk=mkdocs_obsidian.__main__:main"],
    },
)
